# Save and resume progress in lightcards
# Armaan Bhojwani 2021

import hashlib
import os
import pickle

xdg = os.environ.get("XDG_CACHE_HOME")
if xdg:
    dired = f"{os.path.expanduser('~')}/{xdg}/lightcards/"
else:
    dired = f"{os.path.expanduser('~')}/.cache/lightcards/"


def name_gen(stra):
    """Generate hash of stack for name of pickle file"""
    return hashlib.md5(str([str(x) for x in stra]).encode("utf-8")).hexdigest()


def make_dirs(dired):
    """mkdir -p equivalent"""
    if not os.path.exists(dired):
        os.makedirs(dired)


def dump(obj, stra):
    """Write pickle file"""
    make_dirs(dired)

    pickle.dump(obj, open(f"{dired}/{name_gen(stra)}.p", "wb"))


def dive(stra):
    """Get pickle file"""
    file = f"{dired}/{name_gen(stra)}.p"
    make_dirs(dired)
    if os.path.exists(file):
        return pickle.load(open(file, "rb"))
    else:
        return False


def purge(stra):
    """Delete pickle file"""
    file = f"{dired}/{name_gen(stra)}.p"
    if os.path.exists(file):
        os.remove(file)



# Parse lightcards config file
# Armaan Bhojwani 2021

import sys
from pathlib import Path
import os


class ConfigException(BaseException):
    def __init__(self, message):
        self.message = message
        print(f"lightcards: {self.message}")
        sys.exit(4)


def read_file(file):
    config = {}
    file = str(file)
    files = []
    local_xdg = f"{os.path.expanduser('~')}/{os.environ.get('XDG_CACHE_HOME')}/lightcards/config.py"
    local = f"{os.path.expanduser('~')}/.config/lightcards/config.py"
    world = "/etc/lightcards/config.py"

    if os.path.exists(world):
        files.append(world)
    if os.path.exists(local_xdg):
        files.append(local_xdg)
    if os.path.exists(local):
        files.append(local)

    files.append(file)
    if not os.path.exists(file):
        raise ConfigException(f'"{file}": No such file or directory') from None

    for f in files:
        exec(Path(str(f)).read_text(), {}, config)

    return config



# Classes pertaining to the card deck
# Armaan Bhojwani 2021


class Card:
    """Class containing the card information."""

    def __init__(self, inp):
        self.starred = False
        self.side = 0
        self.front = ""
        self.back = ""
        if len(inp) >= 1:
            self.front = inp[0]
        if len(inp) >= 2:
            self.back = inp[1]

    def __str__(self):
        return f"{self.front}, {self.back}"

    def unStar(self):
        self.starred = False

    def star(self):
        self.starred = True

    def toggleStar(self):
        if self.starred:
            self.starred = False
        else:
            self.starred = True

    def printStar(self):
        if self.starred:
            return "★ Starred ★"
        else:
            return "Not starred"

    def get(self, smart=True):
        if self.side == 1 and smart:
            return (self.back, self.front)
        else:
            return (self.front, self.back)

    def flip(self):
        if self.side == 0:
            self.side = 1
        else:
            self.side = 0

    def get_reverse(self):
        if self.side == 0:
            return 1
        else:
            return 0


class Status:
    """Keeps track of where in the deck the user is"""

    def __init__(self):
        self.index = 0
        self.side = 0

    def forward(self, stack):
        if self.index != len(stack):
            self.index += 1

    def back(self):
        if not self.index < 1:
            self.index -= 1

    def get_reverse(self):
        if self.side == 0:
            return 1
        else:
            return 0



# Markdown flashcard utility
# Armaan Bhojwani 2021

import argparse
import curses
import pkg_resources
from random import shuffle
import sys

from . import parse, progress, config
from .display import Display
from .deck import Status


def parse_args():
    """Parse command line arguments"""
    parser = argparse.ArgumentParser(
        description="Terminal flashcards from Markdown"
    )
    parser.add_argument(
        "-c",
        "--config",
        metavar="config_file",
        type=str,
        default="/dev/null",
        help="specify custom config file",
    )
    parser.add_argument(
        "-V",
        "--view",
        metavar="1-3",
        type=int,
        choices=range(1, 4),
        help="specify which view to start in",
    )
    parser.add_argument("inp", metavar="input_files", type=str, nargs="+")
    parser.add_argument(
        "-l",
        "--lenient",
        action="store_true",
        help="don't raise exception if tables are malformed",
    )
    parser.add_argument(
        "-t",
        "--table",
        metavar="num_table",
        type=int,
        help="specify which table to use if multiple are given",
    )
    parser.add_argument(
        "-a",
        "--alphabetize",
        action="store_true",
        help="alphabetize card order",
    )
    parser.add_argument(
        "-p",
        "--purge",
        action="store_true",
        help="delete cache before starting",
    )
    parser.add_argument(
        "-r", "--reverse", action="store_true", help="reverse card order"
    )
    parser.add_argument(
        "-s", "--shuffle", action="store_true", help="shuffle card order"
    )
    parser.add_argument(
        "-v",
        "--version",
        action="version",
        version=f"lightcards {pkg_resources.require('lightcards')[0].version}",
    )
    return parser.parse_args()


def show(args, stack, headers, conf):
    """
    Get objects from cache, manipulate deck according to passed arguments, and
    send it to the display functions
    """
    # Purge caches if asked
    if args.purge:
        progress.purge(get_orig()[1])

    # Check for caches
    idx = Status()
    cache = progress.dive(get_orig()[1])
    if cache and conf["cache"]:
        (stack) = cache

    # Manipulate deck
    if args.shuffle or conf["shuffle"]:
        shuffle(stack)
    if args.alphabetize or conf["alphabetize"]:
        stack.sort(key=lambda x: x.front)
    if args.reverse or conf["reverse"]:
        stack.reverse()

    # Set view
    if args.view:
        view = args.view
    else:
        view = conf["default_view"]

    # Send to display
    win = Display(stack, headers, idx, view, args, conf)
    try:
        curses.wrapper(win.run)
    except curses.error as e:
        raise e


def get_orig():
    """Return original header and stack"""
    return (headers, stack)


def main(args=sys.argv):
    args = parse_args()
    conf = config.read_file(args.config)

    if not conf["debug"]:
        sys.tracebacklimit = 0

    global headers, stack
    (headers, stack) = parse.parse_html(parse.md2html(args.inp), args, conf)

    show(args, stack, headers, conf)


if __name__ == "__main__":
    main()



# Display card output and retreive input
# Armaan Bhojwani 2021

import curses
import curses.panel
import os
from random import shuffle
import sys
import textwrap
import time

from . import runner, progress, parse


def panel_create(x, y):
    """Create popup panels to a certain scale"""
    win = curses.newwin(x, y)
    panel = curses.panel.new_panel(win)
    win.erase()
    return (win, panel)


class Quit:
    def __init__(self, outer, mlines=5, mcols=20):
        self.outer = outer
        (self.win, self.panel) = panel_create(mlines, mcols)
        self.panel.top()
        self.panel.hide()

        self.win.addstr(
            1,
            2,
            "QUIT LIGHTCARDS?",
            curses.color_pair(1) + curses.A_BOLD,
        )
        self.win.hline(2, 1, curses.ACS_HLINE, mcols)
        self.win.addstr(3, 1, "Quit? [y/n]")

        self.win.box()

    def disp(self):
        """Display quit confirmation screen"""
        (mlines, mcols) = self.outer.win.getmaxyx()
        self.win.mvwin(int(mlines / 2) - 3, int(mcols / 2) - 10)
        self.panel.show()
        if self.outer.config["quit_confirmation"]:
            while True:
                key = self.win.getkey()
                if key == "y":
                    break
                elif key == "n":
                    self.panel.hide()
                    self.outer.get_key()


class Panel:
    def __init__(self, outer, mlines, mcols):
        self.outer = outer
        (self.win, self.panel) = panel_create(mlines, mcols)
        self.panel.top()
        self.panel.hide()

    def config_get(self, setting, cut=28):
        return str(list(self.outer.config[setting][:cut])).replace("'", "")


class Help(Panel):
    def __init__(self, outer, mlines=23, mcols=52):
        """Initialize help screen"""
        super().__init__(outer, mlines, mcols)
        c = self.config_get

        text = [
            "Welcome to Lightcards. Here are some keybindings",
            "to get you started:",
            "",
            f"{c('card_prev')}: previous card",
            f"{c('card_next')}: next card",
            f"{c('card_flip')}: flip card",
            f"{c('card_star')}: star card",
            f"{c('card_first')}: go to first card",
            f"{c('card_last')}: go to last card",
            f"{c('help_disp')}: open this help menu",
            f"{c('menu_disp')}: open the control menu",
            f"{c('view_one')}: switch to view one",
            f"{c('view_two')}: switch to view two",
            f"{c('view_three')}: switch to view three",
            f"{c('quit_key')}: quit",
            "",
            "More information can be found in the man page, or",
            "by running `lightcards --help`.",
            "",
            f"Press {c('help_disp')} to go back.",
        ]

        self.win.addstr(
            1,
            int(mcols / 2) - 8,
            "LIGHTCARDS HELP",
            curses.color_pair(1) + curses.A_BOLD,
        )
        self.win.hline(2, 1, curses.ACS_HLINE, mcols)

        for i, content in enumerate(text, 3):
            self.win.addstr(i, 1, content)

        self.win.box()

    def disp(self):
        """Display help screen"""
        (mlines, mcols) = self.outer.win.getmaxyx()
        self.win.mvwin(int(mlines / 2) - 12, int(mcols / 2) - 25)
        self.panel.show()

        while True:
            key = self.win.getkey()
            if key in self.outer.config["quit_key"]:
                self.outer.leave()
            elif key in self.outer.config["help_disp"]:
                self.panel.hide()
                self.outer.get_key()


class Menu(Panel):
    def __init__(self, outer, mlines=17, mcols=44):
        """Initialize the menu with content"""
        super().__init__(outer, mlines, mcols)
        c = self.config_get

        self.win.addstr(
            1,
            int(mcols / 2) - 8,
            "LIGHTCARDS MENU",
            curses.color_pair(1) + curses.A_BOLD,
        )
        self.win.hline(2, 1, curses.ACS_HLINE, mcols)
        env = os.environ.get("EDITOR", "$EDITOR")[:15]
        text = [
            f"{c('menu_reset')}: reset stack to original state",
            f"{c('menu_alphabetize')}: alphabetize stack",
            f"{c('menu_shuffle')}: shuffle stack",
            f"{c('menu_reverse')}: reverse stack order",
            f"{c('menu_unstar')}: unstar all",
            f"{c('menu_star')}: star all",
            f"{c('menu_stars_only')}: update stack to include starred only",
            f"{c('menu_open_file')}: open the input file in {env}",
            "",
            f"{c('menu_restart')}: restart",
            f"{c('menu_disp')}: close menu",
        ]

        for i, content in enumerate(text, 3):
            self.win.addstr(i, 1, content)

        self.win.box()

    def clear_msg(self):
        for i in range(42):
            self.win.addch(15, i + 1, " ")

    def menu_print(self, string, err=False):
        """Print messages on the menu screen"""
        if err:
            color = curses.color_pair(2)
        else:
            color = curses.color_pair(1)

        self.win.addstr(15, 1, string, color)
        self.menu_grab()

    def menu_grab(self):
        """Grab keypresses on the menu screen"""
        while True:
            key = self.win.getkey()
            if (
                key
                in self.outer.config["menu_disp"]
                + self.outer.config["menu_restart"]
            ):
                self.panel.hide()
                self.outer.get_key()
            elif key in self.outer.config["quit_key"]:
                self.outer.leave()
            elif key in self.outer.config["menu_reset"]:
                self.outer.stack = runner.get_orig()[1]
                self.menu_print("Stack reset!")
            elif key in self.outer.config["menu_alphabetize"]:
                self.outer.stack.sort(key=lambda x: x.front)
                self.menu_print("Stack alphabetized!")
            elif key in self.outer.config["menu_unstar"]:
                [x.unStar() for x in self.outer.stack]
                self.menu_print("All unstarred!")
            elif key in self.outer.config["menu_star"]:
                [x.star() for x in self.outer.stack]
                self.menu_print("All starred!")
            elif key in self.outer.config["menu_reverse"]:
                self.outer.stack.reverse()
                self.menu_print("Stack reversed!")
            elif key in self.outer.config["menu_shuffle"]:
                shuffle(self.outer.stack)
                self.menu_print("Stack shuffled!")
            elif key in self.outer.config["menu_open_file"]:
                curses.endwin()
                os.system(f"$EDITOR {self.outer.input_file}"),
                (self.outer.headers, self.outer.stack) = parse.parse_html(
                    parse.md2html(self.outer.input_file),
                    self.outer.args,
                    self.outer.config,
                )
                self.outer.get_key()
            elif key in self.outer.config["menu_stars_only"]:
                # Check if there are any starred cards before proceeding, and
                # if not, don't allow to proceed and show an error message
                cont = False
                for x in self.outer.stack:
                    if x.starred:
                        cont = True
                        break

                if cont:
                    self.outer.stack = [
                        x for x in self.outer.stack if x.starred
                    ]
                    self.menu_print("Stars only!")
                else:
                    self.menu_print("ERR: None are starred!", err=True)
            elif key in self.outer.config["menu_restart"]:
                self.outer.obj.index = 0
                self.outer.get_key()

    def disp(self):
        """
        Display a menu offering multiple options on how to manipulate the deck
        and to continue
        """
        self.clear_msg()

        (mlines, mcols) = self.outer.win.getmaxyx()
        self.win.mvwin(int(mlines / 2) - 8, int(mcols / 2) - 22)
        self.panel.show()

        self.menu_grab()


class Display:
    def __init__(self, stack, headers, obj, view, args, conf):
        self.stack = stack
        self.headers = headers
        self.obj = obj
        self.view = view
        self.input_file = args.inp
        self.config = conf
        self.args = args

    def run(self, stdscr):
        """Set important options that require stdscr before starting"""
        self.win = stdscr
        curses.curs_set(0)  # Hide cursor
        curses.use_default_colors()  # Allow transparency
        curses.init_pair(1, self.config["highlight_color"], -1)
        curses.init_pair(2, self.config["error_color"], -1)
        curses.init_pair(3, self.config["starred_color"], -1)

        self.main_panel = curses.panel.new_panel(self.win)
        self.menu_obj = Menu(self)
        self.help_obj = Help(self)
        self.quit_obj = Quit(self)

        self.get_key()

    def check_size(self):
        (mlines, mcols) = self.win.getmaxyx()

        while mlines < 24 or mcols < 60:
            self.win.clear()
            self.win.addstr(
                0,
                0,
                textwrap.fill(
                    "Terminal too small! Min size 60x24", width=mcols
                ),
            )
            self.win.refresh()
            (mlines, mcols) = self.win.getmaxyx()
            time.sleep(0.1)
        else:
            self.disp_card()

    def dump(self):
        if self.config["cache"]:
            progress.dump(self.stack, runner.get_orig()[1])

    def leave(self):
        """Pickle stack and confirm before quitting"""
        self.quit_obj.disp()
        if self.obj.index + 1 == len(self.stack):
            self.obj.index = 0

        self.dump()
        sys.exit(0)

    def nstarred(self):
        """Get total number of starred cards"""
        return [card for card in self.stack if card.starred]

    def prep_bar(self):
        # Calculate percent done
        if len(self.stack) <= 1:
            percent = "100"
        else:
            percent = str(
                round(self.obj.index / (len(self.stack) - 1) * 100)
            ).zfill(3)

        # Print yellow if starred
        if self.current_card().starred:
            self.star_color = curses.color_pair(3)
        else:
            self.star_color = curses.color_pair(1)

        # Compose bar text
        self.bar_start = "["
        self.bar_middle = self.current_card().printStar()
        self.bar_end = (
            f"] [{len(self.nstarred())}/{str(len(self.stack))} starred] "
        )
        if self.view != 3:
            self.bar_end += (
                f" [{self.get_side()} ("
                f"{str(int(self.current_card().side) + 1)})]"
            )
        self.bar_end += f" [View {str(self.view)}]"

        self.progress = (
            f"[{percent}% ("
            f"{str(self.obj.index + 1).zfill(len(str(len(self.stack))))}"
            f"/{str(len(self.stack))})] "
        )

    def disp_bar(self):
        """
        Display the statusbar at the bottom of the screen with progress, star
        status, and card side.
        """
        # Put it all togethor
        (mlines, mcols) = self.win.getmaxyx()
        height = mlines - 2
        self.win.addstr(height, 0, self.bar_start, curses.color_pair(1))
        self.win.addstr(
            height, len(self.bar_start), self.bar_middle, self.star_color
        )
        self.win.addstr(
            height,
            len(self.bar_start + self.bar_middle),
            textwrap.shorten(self.bar_end, width=mcols - 20, placeholder="…"),
            curses.color_pair(1),
        )

        self.win.addstr(
            height + 1,
            0,
            self.progress,
            curses.color_pair(1),
        )

        for i in range(
            int(
                self.obj.index
                / (len(self.stack) - 1)
                * (mcols - len(self.progress))
                - 1
            )
        ):
            self.win.addch(
                height + 1,
                i + len(self.progress),
                self.config["progress_char"],
                curses.color_pair(1),
            )

        self.win.hline(mlines - 3, 0, 0, mcols)

    def wrap_width(self):
        """Calculate the width at which the body text should wrap"""
        (_, mcols) = self.win.getmaxyx()
        wrap_width = mcols - 20
        if wrap_width > 80:
            wrap_width = 80
        return wrap_width

    def get_side(self):
        if self.obj.side == 0:
            return self.headers[self.current_card().side]
        else:
            return self.headers[self.current_card().get_reverse()]

    def disp_card(self):
        (_, mcols) = self.win.getmaxyx()
        self.main_panel.bottom()
        self.prep_bar()
        num_done = str(self.obj.index + 1).zfill(len(str(len(self.stack))))

        if self.view in [1, 2, 4]:
            """
            Display the contents of the card.
            Shows a header, a horizontal line, and the contents of the current
            side.
            """
            # If on the back of the card, show the content of the front side in
            # the header
            if self.view == 1:
                self.obj.side = 0
            elif self.view == 2:
                self.obj.side = 1

            if self.current_card().side == 0:
                top = num_done + " | " + self.get_side()
            else:
                top = (
                    num_done
                    + " | "
                    + self.get_side()
                    + ' | "'
                    + str(self.current_card().get()[self.obj.get_reverse()])
                    + '"'
                )

            self.win.clear()
            self.win.addstr(
                0,
                0,
                textwrap.shorten(top, width=mcols - 20, placeholder="…"),
                curses.A_BOLD,
            )

            # Show current side
            self.win.addstr(
                2,
                0,
                textwrap.fill(
                    self.current_card().get()[self.obj.side],
                    width=self.wrap_width(),
                ),
            )

        elif self.view == 3:
            """
            Display the contents of the card with both the front and back sides.
            """
            self.win.clear()
            self.win.addstr(
                0,
                0,
                textwrap.shorten(
                    num_done,
                    width=mcols - 20,
                    placeholder="…",
                ),
                curses.A_BOLD,
            )

            # Show card content
            self.win.addstr(
                2,
                0,
                textwrap.fill(
                    self.headers[0] + ": " + self.current_card().front,
                    width=self.wrap_width(),
                )
                + "\n\n"
                + textwrap.fill(
                    self.headers[1] + ": " + self.current_card().back,
                    width=self.wrap_width(),
                ),
            )

        self.win.hline(1, 0, curses.ACS_HLINE, mcols)
        self.disp_sidebar()
        self.disp_bar()

    def current_card(self):
        """Get current card object"""
        return self.stack[self.obj.index]

    def get_key(self):
        """
        Display a card and wait for the input.
        Used as a general way of getting back into the card flow from a menu
        """
        while True:
            self.check_size()
            key = self.win.getkey()
            if key in self.config["quit_key"]:
                self.leave()
            elif key in self.config["card_prev"]:
                self.obj.back()
                self.current_card().side = 0
                self.disp_card()
            elif key in self.config["card_next"]:
                if self.obj.index + 1 == len(self.stack):
                    if self.config["show_menu_at_end"]:
                        self.menu_obj.disp()
                else:
                    self.obj.forward(self.stack)
                    self.current_card().side = 0
                    self.disp_card()
            elif key in self.config["card_flip"] and self.view != 3:
                self.current_card().flip()
                self.disp_card()
            elif key in self.config["card_star"]:
                self.current_card().toggleStar()
                self.disp_card()
            elif key in self.config["card_first"]:
                self.obj.index = 0
                self.current_card().side = 0
                self.disp_card()
            elif key in self.config["card_last"]:
                self.obj.index = len(self.stack) - 1
                self.current_card().side = 0
                self.disp_card()
            elif key in self.config["help_disp"]:
                self.help_obj.disp()
            elif key in self.config["menu_disp"]:
                self.menu_obj.disp()
            elif key in self.config["view_one"]:
                self.view = 1
            elif key in self.config["view_two"]:
                self.view = 2
            elif key in self.config["view_three"]:
                self.view = 3

    def disp_sidebar(self):
        """Display a sidebar with the starred terms"""
        (mlines, mcols) = self.win.getmaxyx()
        left = mcols - 19

        self.win.addstr(
            0,
            mcols - 16,
            "STARRED CARDS",
            curses.color_pair(3) + curses.A_BOLD,
        )
        self.win.vline(0, mcols - 20, 0, mlines - 3)

        nstarred = self.nstarred()
        for i, card in enumerate(nstarred):
            term = card.get(smart=False)[0]
            if len(term) > 18:
                term = term[:18] + "…"

            if i > mlines - 6:
                for i in range(19):
                    self.win.addch(mlines - 4, left + i, " ")

                self.win.addstr(
                    mlines - 4,
                    left,
                    f"({len(nstarred) - i - 2} more)",
                )
            else:
                self.win.addstr(2 + i, left, term)

        if len(self.nstarred()) == 0:
            self.win.addstr(2, left, "None starred")



# Parse markdown table into tuple of lists
# Armaan Bhojwani 2021

from bs4 import BeautifulSoup
import markdown

from .deck import Card


def md2html(file):
    """Use the markdown module to convert input to HTML"""
    outp = ""
    for i in file:
        try:
            outp += markdown.markdown(
                open(i, "r").read(), extensions=["tables"]
            )
        except FileNotFoundError:
            raise Exception(
                f'lightcards: "{i}": No such file or directory'
            ) from None

    return outp


def parse_html(html, args, conf):
    """Use BeautifulSoup to parse the HTML"""

    def clean_text(inp):
        return inp.get_text().rstrip()

    soup = BeautifulSoup(html, "html.parser")
    outp, ths = [], []

    if args.table:
        table_num = args.table
    elif conf["table"]:
        table_num = conf["table"]
    else:
        table_num = False

    for i, table in enumerate(soup.find_all("table"), start=1):
        ths = table.find_all("th")
        if len(ths) != 2:
            if conf["lenient"] or not args.lenient:
                raise Exception("lightcards: Headings malformed")
        elif (table_num and i == table_num) or not table_num:
            try:
                for x in table.find_all("tr"):
                    y = x.find_all("td")
                    if y:
                        outp.append(Card(tuple([clean_text(z) for z in y])))
            except AttributeError:
                raise Exception("lightcards: No table found") from None

    # Return a tuple of nested lists
    return ([clean_text(x) for x in ths], outp)



from setuptools import setup
import os
import shutil

pwd = os.path.abspath(os.path.dirname(__file__))
with open(os.path.join(pwd, "README.md"), encoding="utf-8") as f:
    long_description = f.read()


def mkdir(dir):
    try:
        os.makedirs(dir)
    except FileExistsError:
        pass


if os.geteuid() == 0:
    mkdir("/etc/lightcards/")
    shutil.copyfile("./config.py", "/etc/lightcards/config.py")
else:
    xdg = os.environ.get("XDG_CONFIG_HOME")
    xdg_dest = f"{xdg}/lightcards/config.py"

    home = os.path.expanduser("~")
    home_dest = f"{home}/.config/lightcards/config.py"

    if xdg and not os.path.exists(xdg_dest):
        mkdir(f"{xdg}/lightcards")
        shutil.copyfile("./config.py", xdg_dest)
    elif not os.path.exists(home_dest):
        mkdir(f"{home}/.config/lightcards")
        shutil.copyfile("./config.py", home_dest)


setup(
    name="lightcards",
    version="0.7.0",
    description="Terminal flashcards from Markdown",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://lightcards.armaanb.net",
    author="Armaan Bhojwani",
    author_email="me@armaanb.net",
    license="MIT",
    packages=["lightcards"],
    install_requires=["beautifulsoup4", "markdown"],
    data_files=[
        ("man/man1", ["man/lightcards.1"]),
        ("man/man5", ["man/lightcards-config.5"]),
    ],
    entry_points={
        "console_scripts": ["lightcards=lightcards:main"],
    },
    classifiers=[
        "Intended Audience :: Education",
        "Environment :: Console :: Curses",
        "License :: OSI Approved :: MIT License",
        "Topic :: Education",
    ],
)
